==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-networkmonitor/networkmonitor_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Διεπαφή δικτύου &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation>Διαβιβασμένα %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation>Ειλημμένα %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <source>LXQt Network Monitor settings</source>
        <translation>Ρυθμίσεις της επίβλεψης δικτύου του LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation>Ρυθμίσεις του επόπτη δικτύου</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Διεπαφή</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Αποδιαμορφωτής</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Εποπτεία</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Δίκτυο</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Ασύρματο</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Εικονίδιο</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-networkmonitor/networkmonitor_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Διεπαφή δικτύου &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation>Διαβιβασμένα %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation>Ειλημμένα %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <source>LXQt Network Monitor settings</source>
        <translation type="vanished">Ρυθμίσεις της επίβλεψης δικτύου του LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation>Ρυθμίσεις του επόπτη δικτύου</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Διεπαφή</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Αποδιαμορφωτής</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Εποπτεία</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Δίκτυο</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Ασύρματο</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Εικονίδιο</translation>
    </message>
</context>
</TS>
